==> pegasus-service-purchase-1.0-sources.jar: com/thebeastshop/pegasus/service/purchase/flower/vo/FpcsActualChannelItemVO.java <==
package com.thebeastshop.pegasus.service.purchase.flower.vo;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by Administrator on 2016/4/13.
 * @author gongjun
 * @since 2016-04-13 11:12
 */
public class FpcsActualChannelItemVO {

    private String channelCode;

    private Date purchaseDate;

    private String skuCode;

    private String skuType;

    private String skuName;

    private String unit;

    private String purchaseUnit;

    private Integer purchaseUnitNumber;

    private BigDecimal price;

    private Integer quantity;

    private BigDecimal totalPrice;

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuType() {
        return skuType;
    }

    public void setSkuType(String skuType) {
        this.skuType = skuType;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getPurchaseUnit() {
        return purchaseUnit;
    }

    public void setPurchaseUnit(String purchaseUnit) {
        this.purchaseUnit = purchaseUnit;
    }

    public Integer getPurchaseUnitNumber() {
        return purchaseUnitNumber;
    }

    public void setPurchaseUnitNumber(Integer purchaseUnitNumber) {
        this.purchaseUnitNumber = purchaseUnitNumber;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
}

==> pegasus-service-purchase-2.0.8-sources.jar: com/thebeastshop/pegasus/service/purchase/flower/vo/FpcsActualChannelItemVO.java <==
package com.thebeastshop.pegasus.service.purchase.flower.vo;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Created by Administrator on 2016/4/13.
 * @author gongjun
 * @since 2016-04-13 11:12
 */
public class FpcsActualChannelItemVO {

    private String channelCode;

    private String channelName;

    private String supplierName;

    private Date purchaseDate;

    private String skuCode;

    private String skuType;

    private String skuName;

    private String unit;

    private String purchaseUnit;

    private Integer purchaseUnitNumber;

    private BigDecimal price;

    private Integer quantity;

    private BigDecimal totalPrice;

    private Long purchaseId;

    private String purchaseCode;

    private String skuAndQuantity;

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Date getPurchaseDate() {
        return purchaseDate;
    }

    public void setPurchaseDate(Date purchaseDate) {
        this.purchaseDate = purchaseDate;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getSkuType() {
        return skuType;
    }

    public void setSkuType(String skuType) {
        this.skuType = skuType;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getPurchaseUnit() {
        return purchaseUnit;
    }

    public void setPurchaseUnit(String purchaseUnit) {
        this.purchaseUnit = purchaseUnit;
    }

    public Integer getPurchaseUnitNumber() {
        return purchaseUnitNumber;
    }

    public void setPurchaseUnitNumber(Integer purchaseUnitNumber) {
        this.purchaseUnitNumber = purchaseUnitNumber;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }

    public String getChannelName() {
        return channelName;
    }

    public void setChannelName(String channelName) {
        this.channelName = channelName;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getPurchaseId() {
        return purchaseId;
    }

    public void setPurchaseId(Long purchaseId) {
        this.purchaseId = purchaseId;
    }

    public String getSkuAndQuantity() {
        return skuAndQuantity;
    }

    public void setSkuAndQuantity(String skuAndQuantity) {
        this.skuAndQuantity = skuAndQuantity;
    }

    public String getPurchaseCode() {
        return purchaseCode;
    }

    public void setPurchaseCode(String purchaseCode) {
        this.purchaseCode = purchaseCode;
    }
}
